
From: Paul Mackerras <paulus@samba.org>

The code that went into arch/ppc/kernel/signal.c recently to handle process
freezing seems to contain a dubious assumption: that a process that calls
do_signal when PF_FREEZE is set will have entered the kernel because of a
system call.  This patch removes that assumption.

Signed-off-by: Paul Mackerras <paulus@samba.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/ppc/kernel/signal.c |    4 +---
 1 files changed, 1 insertion(+), 3 deletions(-)

diff -puN arch/ppc/kernel/signal.c~ppc32-fix-bogosity-in-process-freezing-code arch/ppc/kernel/signal.c
--- 25/arch/ppc/kernel/signal.c~ppc32-fix-bogosity-in-process-freezing-code	2005-04-03 21:48:01.000000000 -0700
+++ 25-akpm/arch/ppc/kernel/signal.c	2005-04-03 21:48:01.000000000 -0700
@@ -708,7 +708,6 @@ int do_signal(sigset_t *oldset, struct p
 	if (current->flags & PF_FREEZE) {
 		refrigerator(PF_FREEZE);
 		signr = 0;
-		ret = regs->gpr[3];
 		if (!signal_pending(current))
 			goto no_signal;
 	}
@@ -719,7 +718,7 @@ int do_signal(sigset_t *oldset, struct p
 	newsp = frame = 0;
 
 	signr = get_signal_to_deliver(&info, &ka, regs, NULL);
-
+ no_signal:
 	if (TRAP(regs) == 0x0C00		/* System Call! */
 	    && regs->ccr & 0x10000000		/* error signalled */
 	    && ((ret = regs->gpr[3]) == ERESTARTSYS
@@ -735,7 +734,6 @@ int do_signal(sigset_t *oldset, struct p
 			regs->gpr[3] = EINTR;
 			/* note that the cr0.SO bit is already set */
 		} else {
-no_signal:
 			regs->nip -= 4;	/* Back up & retry system call */
 			regs->result = 0;
 			regs->trap = 0;
_
